@@ -6,14 +6,14 @@ set -e
 php --server localhost:10101 --docroot debian/tests/data &
 SERVER_PID=$!
 
-# the startup can be racy making the test a false-positive
-# wait up to 10 seconds until it is ready
-r=0
-until [ "$r" -ge 100 ]; do
-    nc -z localhost 10101 && echo "PRE: Connection ready" && break
-    sleep 0.1
-    echo "PRE: Retry Connection"
-done
+set +e
+curl --fail --silent --output /dev/null http://localhost:10101/foaf.rdf
+if [ $? -ne 0 ]
+then
+    # Likely 22, the server may not be ready, give it a bit of time.
+    sleep 2
+fi
+set -e
 
 # A graphviz source file can be created.
 php debian/tests/rapper.php > sample.dot
